@@ -19,12 +19,12 @@
 PG_MODULE_MAGIC;
 
 extern PGDLLEXPORT void _PG_init(void);
-extern PGDLLEXPORT void pgroonga_standby_maintainer_apply_wal(Datum datum)
-	pg_attribute_noreturn();
-extern PGDLLEXPORT void pgroonga_standby_maintainer_maintain(Datum datum)
-	pg_attribute_noreturn();
-extern PGDLLEXPORT void pgroonga_standby_maintainer_main(Datum datum)
-	pg_attribute_noreturn();
+extern PGDLLEXPORT pg_noreturn void
+pgroonga_standby_maintainer_apply_wal(Datum datum) pg_attribute_noreturn();
+extern PGDLLEXPORT pg_noreturn void
+pgroonga_standby_maintainer_maintain(Datum datum) pg_attribute_noreturn();
+extern PGDLLEXPORT pg_noreturn void
+pgroonga_standby_maintainer_main(Datum datum) pg_attribute_noreturn();
 
 #define TAG "pgroonga: standby-maintainer"
 
@@ -237,8 +237,9 @@ pgroonga_standby_maintainer_maintain(Datum databaseInfoDatum)
 			}
 			else
 			{
-				indexName = VARDATA_ANY(indexNameDatum);
-				indexNameSize = VARSIZE_ANY_EXHDR(indexNameDatum);
+				indexName = VARDATA_ANY(DatumGetPointer(indexNameDatum));
+				indexNameSize =
+					VARSIZE_ANY_EXHDR(DatumGetPointer(indexNameDatum));
 			}
 			BGWORKER_SET_INDEX_NAME(worker, indexName, indexNameSize);
 		}
